import 'dart:io';

import 'package:ansicolor/ansicolor.dart';
import 'package:flutter/foundation.dart';

class AdpackSettings {
  static final AdpackSettings _instance = AdpackSettings._internal();

  late final bool _isDebug;
  late final String _appsFlyerKey;
  late final String _supabaseUrl;
  late final String _supabaseKey;
  late final String _appId;
  bool _isInit = false;

  AdpackSettings._internal();

  factory AdpackSettings.initialize({
    required String appsFlyerKey,
    String? appId,
    required String supabaseUrl,
    required String supabaseKey,
    bool isDebug = kDebugMode,
  }) {
    if (!_instance._isInit) {
      if (Platform.isIOS) {
        assert(appId == null, 'App ID is required for iOS');
        throw 'App ID is required for iOS';
      }
      _instance._appsFlyerKey = appsFlyerKey;
      _instance._appId = appId ?? '';
      _instance._supabaseUrl = supabaseUrl;
      _instance._supabaseKey = supabaseKey;
      _instance._isDebug = isDebug;
      _instance._isInit = true;

      ansiColorDisabled = !isDebug;
    }
    return _instance;
  }

  factory AdpackSettings() => _instance;

  bool get isDebug => _isDebug;
  String get appsFlyerKey => _appsFlyerKey;
  String get appId => _appId;
  String get supabaseUrl => _supabaseUrl;
  String get supabaseKey => _supabaseKey;

  void log(String message) {
    if (_isDebug) {
      AnsiPen pen = AnsiPen()..yellow(bold: true);

      List<String> msgLst = _splitString(message, 1000);
      // ignore: avoid_print
      for (int i = 0; i < msgLst.length; i++) {
        debugPrint(pen(msgLst[i]));
      }
    }
  }

  List<String> _splitString(String input, int chunkSize) {
    List<String> chunks = [];
    for (int i = 0; i < input.length; i += chunkSize) {
      int end = (i + chunkSize < input.length) ? i + chunkSize : input.length;
      chunks.add(input.substring(i, end));
    }
    return chunks;
  }
}
