import 'package:adpack/src/presentation/widgets/loading_page.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../../core/adpack_settings.dart';
import '../cubit/adpack_cubit.dart';
import 'destination.dart';

class Adpack extends StatelessWidget {
  final Widget child;
  final AdpackSettings settings;
  final LoadingPage? loadingPage;

  const Adpack({
    super.key,
    required this.child,
    required this.settings,
    this.loadingPage,
  });

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) => AdpackCubit(),
      child: Builder(
        builder: (context) {
          return BlocBuilder<AdpackCubit, AdpackState>(
            builder: (context, state) {
              if (state.status == AdpackStatus.noConnection) {
                return child;
              }
              if (state.status == AdpackStatus.loaded) {
                return Destination(destination: state.destination!);
              }
              return loadingPage ??
                  const LoadingPage(
                    loadingWidget: CircularProgressIndicator(),
                  );
            },
          );
        },
      ),
    );
  }
}
